# Run meta-analysis of restoration effects vs distance

require(metafor)
library(openxlsx)
library(stringr)

output_dir = "C:/wetlands/regr_block"
setwd(output_dir)

# Function definitions
# ----------------------
mlabfun <- function(text, res) {
   paste(text, 
#   " (Q =", (formatC(res$QE, digits=2, format="f")),
#  ", df =", (res$k - res$p),
#   ", I^2 =", (formatC(res$I2, digits=1, format="f")), "%, ",
#   "tau^2 =", (formatC(res$tau2, digits=2, format="f")),
   ")")}

# Constants
# ----------------------

# No of decimal digits for forest plot rows
decimals_rows = 0
# No of decimal digits for forest plot axis tick labels
decimals_axis = 0

# Start of program
# ----------------------

# Load data from combined effect size file
esd <- read.xlsx("C:/wetlands/Additional file 5.xlsx")

# Update header
names(esd) <- esd[1,]

# Drop first row of data (the second row of header information)
esd <- esd[-c(1), ]

# Drop treatment categories that are not restoration or creation
esd <- esd[(esd$"Drainage/Restoration/Creation" == "Restoration" | esd$"Drainage/Restoration/Creation" == "Creation"),]

# Drop rows without treatment id (not included in meta-analysis)
esd <- esd[!(is.na(esd$"Regression Treatment ID")),]

# Drop limnic shore wetlands
esd <- esd[(esd$"Wetland type" != "Limnic shore wetland"),]

# Set data types for some columns we need in the analysis
esd$"Regression slope" <- as.numeric(esd$"Regression slope")
esd$"Regression slope.SE" <- as.numeric(esd$"Regression slope.SE")
esd$"Regression intercept" <- as.numeric(esd$"Regression intercept")
esd$"Regression intercept.SE" <- as.numeric(esd$"Regression intercept.SE")
esd$"Average or estimated ditch spacing (m)" <- as.numeric(esd$"Average or estimated ditch spacing (m)")
esd$"Average peat depth (cm)" <- as.numeric(esd$"Average peat depth (cm)")
esd$"Time since intervetion (min, yrs)" <- as.numeric(esd$"Time since intervetion (min, yrs)") 
esd$"Time since intervetion (max, yrs)" <- as.numeric(esd$"Time since intervetion (max, yrs)") 
esd$"Intervention magnitude (depth/height in cm)" <- as.numeric(esd$"Intervention magnitude (depth/height in cm)")
esd$"Slope (degrees)" <- as.numeric(esd$"Slope (degrees)")
esd$"Maximum distance of gwl measurements (m)" <- as.numeric(esd$"Maximum distance of gwl measurements (m)")

# Rename a few columns we need to work with in metafor (which can't handle column names in quotes)
names(esd)[names(esd) == "Regression slope"] <- "Regr_slope"
names(esd)[names(esd) == "Regression slope.SE"] <- "Regr_slope_SE"
names(esd)[names(esd) == "Regression slope.Replication"] <- "Regr_slope_Replication"
names(esd)[names(esd) == "Regression intercept"] <- "Regr_intercept"
names(esd)[names(esd) == "Regression intercept.SE"] <- "Regr_intercept_SE"
names(esd)[names(esd) == "Wetland type"] <- "Wetland_type"
names(esd)[names(esd) == "Climate zone"] <- "Climate_zone"
names(esd)[names(esd) == "Average peat depth (cm)"] <- "Peat_depth"
names(esd)[names(esd) == "Average or estimated ditch spacing (m)"] <- "Ditch_spacing"
names(esd)[names(esd) == "True replications (intervention level, count only intervention sites, not control)"] <- "True_reps"
names(esd)[names(esd) == "Time since intervetion (min, yrs)"] <- "Time_since_intervention_min"
names(esd)[names(esd) == "Time since intervetion (max, yrs)"] <- "Time_since_intervention_max"
names(esd)[names(esd) == "Underlying soil type"] <- "Underlying_soil"
names(esd)[names(esd) == "Intervention magnitude (depth/height in cm)"] <- "Intervention_magnitude"
names(esd)[names(esd) == "Slope (degrees)"] <- "Slope"
names(esd)[names(esd) == "Maximum distance of gwl measurements (m)"] <- "Max_dist_for_gwl_sampling"
names(esd)[names(esd) == "Confined/mirrored (by next ditch) or open-ended transect"] <- "Transect_type"
names(esd)[names(esd) == "Groundwater level reference point"] <- "Gwl_ref_point"


# Make a new column with average time since intervention
esd$Time_since_intervention_avg <- rowMeans(esd[,c("Time_since_intervention_min", "Time_since_intervention_max")], na.rm=TRUE)

# Perform a meta-analysis of regression slopes
# --------------------------------------------
# Calculate RE model based on underlying sample size (number of true replications) weights = True_reps
result = rma(measure = "MD", data = esd, yi = Regr_slope, sei = Regr_slope_SE, test = "knha", weights = True_reps)
result

# Set up data frame to save meta-analysis results
df <- data.frame(value = c("slope_main_all"), estimate = c(result$b), SE = c(result$se), ci.lb = c(result$ci.lb), ci.ub = c(result$ci.ub), k = c(result$k), pval = c(result$pval), tau2 = c(result$tau2), I2 = c(result$I2), H2 = c(result$H2), QE = c(result$QE), QEp = c(result$QEp), QM = c(NA), QMp = c(NA))

# Save plot
pdf("forest_regr_block_slope.pdf", height = 4)

# Print a forest plot of slopes
forest(result, slab = esd$"Short ref", 
	header = c("Author and year", "Slope [95% CI]"), 
	cex = 0.75,	xlab = "Slope",	
	digits = c(decimals_rows, decimals_axis),
	ilab = esd$True_reps, ilab.xpos = -40,
	)
text(-40, result$k + 2, "Wetlands", font = 2, cex = .75)
text(-40, -1, sum(as.numeric(result$weights)), font = 1, cex = .75)
# Close graphics
dev.off() 


# Perform a meta-analysis of regression intercept
# --------------------------------------------
# Calculate RE model based on underlying sample size (number of true replications) weights = True_reps
result = rma(measure = "MD", data = esd, yi = Regr_intercept, sei = Regr_intercept_SE, test = "knha", weights = True_reps)
result

# Add results to df for later export
df <- rbind(df, c("intercept_main_all", result$b, result$se, result$ci.lb, result$ci.ub, result$k, result$pval, result$tau2, result$I2, result$H2, result$QE, result$QEp, NA, NA))

# Save plot
pdf("forest_regr_block_intercept.pdf", height = 4)

# Print a forest plot of slopes
forest(result, slab = esd$"Short ref", 
	header = c("Author and year", "Intercept [95% CI]"), 
	cex = 0.75,	xlab = "Intercept",
	digits = c(decimals_rows, decimals_axis),
	ilab = esd$True_reps, ilab.xpos = -65,
	)
text(-65, result$k + 2, "Wetlands", font = 2, cex = .75)
text(-65, -1, sum(as.numeric(result$weights)), font = 1, cex = .75)

# Close graphics
dev.off()

# Sensitivity test - exclude blanket peatland studies 
# -----------------------------------------------

NoBlanketPeatlands = is.na(esd$"Blanket peatland")

result = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Regr_slope, sei = Regr_slope_SE, test = "knha", weights = True_reps)
result

# Save plot
pdf("forest_regr_block_slope_no_blanket_peatlands.pdf", height = 4)

# Print a forest plot of slopes
forest(result, slab = esd[NoBlanketPeatlands,]$"Short ref", 
	header = c("Author and year", "Slope [95% CI]"), 
	cex = 0.75,	xlab = "Slope",
	digits = c(decimals_rows, decimals_axis),
	ilab = esd[NoBlanketPeatlands,]$True_reps, ilab.xpos = -30,	
	)
text(-30, result$k + 2, "Wetlands", font = 2, cex = .75)
text(-30, -1, sum(as.numeric(result$weights)), font = 1, cex = .75)

# Close graphics
dev.off() 

# Add results to df for later export
df <- rbind(df, c("slope_no_blanket_peatlands", result$b, result$se, result$ci.lb, result$ci.ub, result$k, result$pval, result$tau2, result$I2, result$H2, result$QE, result$QEp, NA, NA))

result = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Regr_intercept, sei = Regr_intercept_SE, test = "knha", weights = True_reps)
result

# Save plot
pdf("forest_regr_block_intercept_no_blanket_peatlands.pdf", height = 4)

# Print a forest plot of slopes
forest(result, slab = esd[NoBlanketPeatlands,]$"Short ref", 
	header = c("Author and year", "Intercept [95% CI]"), 
	cex = 0.75,	xlab = "Intercept",
	digits = c(decimals_rows, decimals_axis),
	ilab = esd[NoBlanketPeatlands,]$True_reps, ilab.xpos = -30,	
	)
text(-30, result$k + 2, "Wetlands", font = 2, cex = .75)
text(-30, -1, sum(as.numeric(result$weights)), font = 1, cex = .75)

# Close graphics
dev.off() 

# Add results to df for later export
df <- rbind(df, c("intercept_no_blanket_peatlands", result$b, result$se, result$ci.lb, result$ci.ub, result$k, result$pval, result$tau2, result$I2, result$H2, result$QE, result$QEp, NA, NA))



# Sensitivity test - only blanket peatland studies 
# -----------------------------------------------
OnlyBlanketPeatlands = !(is.na(esd$"Blanket peatland"))

result = rma(measure = "MD", data = esd[OnlyBlanketPeatlands,], yi = Regr_slope, sei = Regr_slope_SE, test = "knha", weights = True_reps)
result

# Save plot
pdf("forest_regr_block_slope_only_blanket_peatlands.pdf", height = 4)

# Print a forest plot of slopes
forest(result, slab = esd[OnlyBlanketPeatlands,]$"Short ref", 
	header = c("Author and year", "Slope [95% CI]"), 
	cex = 0.75,	xlab = "Slope",
	digits = c(decimals_rows, decimals_axis),
	ilab = esd[OnlyBlanketPeatlands,]$True_reps, ilab.xpos = -25,	
	)
text(-25, result$k + 2, "Wetlands", font = 2, cex = .75)
text(-25, -1, sum(as.numeric(result$weights)), font = 1, cex = .75)

# Close graphics
dev.off() 

# Add results to df for later export
df <- rbind(df, c("slope_only_blanket_peatlands", result$b, result$se, result$ci.lb, result$ci.ub, result$k, result$pval, result$tau2, result$I2, result$H2, result$QE, result$QEp, NA, NA))

result = rma(measure = "MD", data = esd[OnlyBlanketPeatlands,], yi = Regr_intercept, sei = Regr_intercept_SE, test = "knha", weights = True_reps)
result

# Save plot
pdf("forest_regr_block_intercept_only_blanket_peatlands.pdf", height = 4)

# Print a forest plot of slopes
forest(result, slab = esd[OnlyBlanketPeatlands,]$"Short ref", 
	header = c("Author and year", "Intercept [95% CI]"), 
	cex = 0.75,	xlab = "Intercept",
	digits = c(decimals_rows, decimals_axis),
	ilab = esd[OnlyBlanketPeatlands,]$True_reps, ilab.xpos = -45,	
	)
text(-45, result$k + 2, "Wetlands", font = 2, cex = .75)
text(-45, -1, sum(as.numeric(result$weights)), font = 1, cex = .75)

# Close graphics
dev.off() 

# Add results to df for later export
df <- rbind(df, c("intercept_only_blanket_peatlands", result$b, result$se, result$ci.lb, result$ci.ub, result$k, result$pval, result$tau2, result$I2, result$H2, result$QE, result$QEp, NA, NA))


# Tests of moderators - slope of regression function
# --------------------------------------

# Investigate the possible influence of peat depth as moderator
result = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Regr_slope, sei = Regr_slope_SE, weights = True_reps, mods = ~ Peat_depth)
result

df <- rbind(df, c("slope_no_blanket_peatlands_moderator_peat_depth", result$b[2], result$se[2], result$ci.lb[2], result$ci.ub[2], result$k, result$pval[2], result$tau2, result$I2, result$H2, result$QE, result$QEp, result$QM, result$QMp))

# Peat depth is not a significant moderator, don't plot
# regplot(res_peatdepth, mod = "Peat_depth", xlim=c(0,300), predlim=c(0,300), xlab="Peat depth (cm)")

# Investigate the possible influence of time since intervention as moderator 
result = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Regr_slope, sei = Regr_slope_SE, weights = True_reps, mods = cbind(Time_since_intervention_avg))
result

df <- rbind(df, c("slope_no_blanket_peatlands_moderator_time_since_intervention", result$b[2], result$se[2], result$ci.lb[2], result$ci.ub[2], result$k, result$pval[2], result$tau2, result$I2, result$H2, result$QE, result$QEp, result$QM, result$QMp))

# Investigate the possible influence of intervention magnitude as moderator 
result = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Regr_slope, sei = Regr_slope_SE, weights = True_reps, mods = ~ Intervention_magnitude)
result

pdf("regr_block_mod_slope_metareg_intervention_magnitude.pdf", height = 5, width = 5)
regplot(result, mod = "Intervention_magnitude", xlim=c(90,250), predlim=c(90,250), xlab="Intervention magnitude (cm)", ylab = "Slope coefficient value")
dev.off()

df <- rbind(df, c("slope_no_blanket_peatlands_moderator_intervention_magnitude", result$b[2], result$se[2], result$ci.lb[2], result$ci.ub[2], result$k, result$pval[2], result$tau2, result$I2, result$H2, result$QE, result$QEp, result$QM, result$QMp))

# Investigate the possible influence of underlying soil type as moderator
# For this test, group all "Till" studies into the same category, otherwise they are too few, and skip "Karst" category (one single study)
esd_soils = data.frame(esd[NoBlanketPeatlands,])
# Remove a subgroup with only one single study
esd_soils <- esd_soils[!(esd_soils$"Underlying_soil" == "Karst and sinkhole terrain"),]
esd_soils$Underlying_soil[esd_soils$Underlying_soil == "Low-permeability till" | esd_soils$Underlying_soil == "Unsorted till"] <- "Till"

# Check how many studies there are in each category
soil_type_counts = table(esd_soils$Underlying_soil)

result = rma(measure = "MD", data = esd_soils, yi = Regr_slope, sei = Regr_slope_SE, test = "knha", mods = ~factor(Underlying_soil) - 1, weights = True_reps)
result

# Save plot
pdf("regr_block_mod_slope_soil_type.pdf", height = 4, width = 10)

# Plot soil type moderators
forest(result$b, sei = result$se, header = c("Underlying soil", "Slope [95% CI]"), 
									slab = c(rownames(soil_type_counts)[1], 
									 rownames(soil_type_counts)[2],
									 rownames(soil_type_counts)[3]
									),
				ilab = as.list(soil_type_counts), ilab.xpos = -50,
				xlim = c(-120, 30),
				# rows = c(2, 1, 4, 3),
				digits = c(decimals_rows, decimals_axis),
				xlab = "Slope", psize = 1

)
par(font=2)
text(-50, 6, "n")
dev.off() 


# Investigate the possible influence of underlying soil type as moderator 
result = rma(measure = "MD", data = esd_soils, yi = Regr_slope, sei = Regr_slope_SE, weights = True_reps, mods = ~ factor(Underlying_soil))
result

# Report the factor as a whole
df <- rbind(df, c("slope_no_blanket_peatlands_moderator_soil_type", result$b[1], result$se[1], result$ci.lb[1], result$ci.ub[1], result$k, result$pval[1], result$tau2, result$I2, result$H2, result$QE, result$QEp, result$QM, result$QMp))

# Investigate the possible influence of ditch spacing as moderator 
result = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Regr_slope, sei = Regr_slope_SE, weights = True_reps, mods = ~ Ditch_spacing)
result

df <- rbind(df, c("slope_no_blanket_peatlands_moderator_ditch_spacing", result$b[2], result$se[2], result$ci.lb[2], result$ci.ub[2], result$k, result$pval[2], result$tau2, result$I2, result$H2, result$QE, result$QEp, result$QM, result$QMp))

# Investigate the possible influence of slope as moderator
# Too few studies (k = 2) to estimate, skip
# result = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Regr_slope, sei = Regr_slope_SE, weights = True_reps, mods = ~ Slope)
# result

# df <- rbind(df, c("slope_no_blanket_peatlands_moderator_slope", result$b[2], result$se[2], result$ci.lb[2], result$ci.ub[2], result$k, result$pval[2], result$tau2, result$I2, result$H2, result$QE, result$QEp, result$QM, result$QMp))
df <- rbind(df, c("slope_no_blanket_peatlands_moderator_slope", "", "", "", "", 2, "", "", "", "", "", "", "", ""))

# Investigate the possible influence of open or closed transect as moderator 
result = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Regr_slope, sei = Regr_slope_SE, weights = True_reps, mods = ~ factor(Transect_type))
result

df <- rbind(df, c("slope_no_blanket_peatlands_moderator_transect_type", result$b[2], result$se[2], result$ci.lb[2], result$ci.ub[2], result$k, result$pval[2], result$tau2, result$I2, result$H2, result$QE, result$QEp, result$QM, result$QMp))

# Investigate the possible influence of climate zone as moderator
result = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Regr_slope, sei = Regr_slope_SE, weights = True_reps, mods = ~ factor(Climate_zone))
result

df <- rbind(df, c("slope_no_blanket_peatlands_moderator_climate_zone", result$b[2], result$se[2], result$ci.lb[2], result$ci.ub[2], result$k, result$pval[2], result$tau2, result$I2, result$H2, result$QE, result$QEp, result$QM, result$QMp))




# Tests of moderators - intercept
# --------------------------------------

# Investigate the possible influence of peat depth as moderator
result = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Regr_intercept, sei = Regr_intercept_SE, weights = True_reps, mods = cbind(Peat_depth))
result

df <- rbind(df, c("intercept_no_blanket_peatlands_moderator_peat_depth", result$b[2], result$se[2], result$ci.lb[2], result$ci.ub[2], result$k, result$pval[2], result$tau2, result$I2, result$H2, result$QE, result$QEp, result$QM, result$QMp))

# Investigate the possible influence of time since intervention as moderator 
result = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Regr_intercept, sei = Regr_intercept_SE, weights = True_reps, mods = cbind(Time_since_intervention_avg))
result

df <- rbind(df, c("intercept_no_blanket_peatlands_moderator_time_since_intervention", result$b[2], result$se[2], result$ci.lb[2], result$ci.ub[2], result$k, result$pval[2], result$tau2, result$I2, result$H2, result$QE, result$QEp, result$QM, result$QMp))

# Investigate the possible influence of intervention magnitude as moderator 
result = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Regr_intercept, sei = Regr_intercept_SE, weights = True_reps, mods = ~ Intervention_magnitude)
result

# Plot this even though not significant to help understanding
pdf("regr_block_mod_intercept_metareg_intervention_magnitude.pdf", height = 5, width = 5)
regplot(result, mod = "Intervention_magnitude", xlim=c(90,250), predlim=c(90,250), xlab="Intervention magnitude (cm)", ylab = "Intercept coefficient value")
dev.off()

df <- rbind(df, c("intercept_no_blanket_peatlands_moderator_intervention_magnitude", result$b[2], result$se[2], result$ci.lb[2], result$ci.ub[2], result$k, result$pval[2], result$tau2, result$I2, result$H2, result$QE, result$QEp, result$QM, result$QMp))


# Investigate the possible influence of underlying soil type as moderator

result = rma(measure = "MD", data = esd_soils, yi = Regr_intercept, sei = Regr_intercept_SE, test = "knha", mods = ~factor(Underlying_soil) - 1, weights = True_reps)
result

# Save plot
pdf("regr_block_mod_intercept_soil_type.pdf", height = 4, width = 10)

# Plot soil type moderators
forest(result$b, sei = result$se, header = c("Underlying soil", "Slope [95% CI]"), 
									slab = c(rownames(soil_type_counts)[1], 
									 rownames(soil_type_counts)[2],
									 rownames(soil_type_counts)[3]
									),
				ilab = as.list(soil_type_counts), ilab.xpos = -50,
				xlim = c(-120, 30),
				# rows = c(2, 1, 4, 3),
				digits = c(decimals_rows, decimals_axis),
				xlab = "Slope", psize = 1

)
par(font=2)
text(-50, 6, "n")
dev.off() 



# Investigate the possible influence of underlying soil type as moderator 
result = rma(measure = "MD", data = esd_soils, yi = Regr_intercept, sei = Regr_intercept_SE, weights = True_reps, mods = ~ factor(Underlying_soil))
result

# Report the factor as a whole
df <- rbind(df, c("intercept_no_blanket_peatlands_moderator_soil_type", result$b[1], result$se[1], result$ci.lb[1], result$ci.ub[1], result$k, result$pval[1], result$tau2, result$I2, result$H2, result$QE, result$QEp, result$QM, result$QMp))

# Investigate the possible influence of ditch spacing as moderator 
result = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Regr_intercept, sei = Regr_intercept_SE, weights = True_reps, mods = ~ Ditch_spacing)
result

df <- rbind(df, c("intercept_no_blanket_peatlands_moderator_ditch_spacing", result$b[2], result$se[2], result$ci.lb[2], result$ci.ub[2], result$k, result$pval[2], result$tau2, result$I2, result$H2, result$QE, result$QEp, result$QM, result$QMp))

# Investigate the possible influence of slope as moderator 
# Too few studies (k = 2) to estimate, skip
# result = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Regr_intercept, sei = Regr_intercept_SE, weights = True_reps, mods = ~ Slope)
# result

# df <- rbind(df, c("intercept_no_blanket_peatlands_moderator_slope", result$b[2], result$se[2], result$ci.lb[2], result$ci.ub[2], result$k, result$pval[2], result$tau2, result$I2, result$H2, result$QE, result$QEp, result$QM, result$QMp))
df <- rbind(df, c("intercept_no_blanket_peatlands_moderator_slope", "", "", "", "", 2, "", "", "", "", "", "", "", ""))

# Investigate the possible influence of open or closed transect as moderator 
result = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Regr_intercept, sei = Regr_intercept_SE, weights = True_reps, mods = ~ factor(Transect_type))
result

df <- rbind(df, c("intercept_no_blanket_peatlands_moderator_transect_type", result$b[2], result$se[2], result$ci.lb[2], result$ci.ub[2], result$k, result$pval[2], result$tau2, result$I2, result$H2, result$QE, result$QEp, result$QM, result$QMp))

# Investigate the possible influence of climate zone as moderator 
result = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Regr_intercept, sei = Regr_intercept_SE, weights = True_reps, mods = ~ factor(Climate_zone))
result

df <- rbind(df, c("intercept_no_blanket_peatlands_moderator_climate_zone", result$b[2], result$se[2], result$ci.lb[2], result$ci.ub[2], result$k, result$pval[2], result$tau2, result$I2, result$H2, result$QE, result$QEp, result$QM, result$QMp))



# Sensitivity test - weighting method
# Publication bias
# and funnel plots based on SE as weights
# -----------------------------------------------

# Investigate if slope results are different if weight is based on standard error (here = how well study data fit a log regression function), instead of number of wetlands
result = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Regr_slope, sei = Regr_slope_SE, test = "knha")
result

df <- rbind(df, c("slope_no_blanket_peatlands_sensitivity_weights_as_study_se", result$b, result$se, result$ci.lb, result$ci.ub, result$k, result$pval, result$tau2, result$I2, result$H2, result$QE, result$QEp, NA, NA))

# Make a funnel plot of effect size vs study variance
pdf("regr_block_funnel_slope.pdf", height = 4, width = 4)
funnel(result, xlab = "Slope")
dev.off() 

# Perform Egger's test of funnel plot assymetry
rt = regtest(result)
df <- rbind(df, c("slope_no_blanket_peatlands_eggers_test_weights_as_study_se", rt$est, NA, rt$ci.lb, rt$ci.ub, NA, rt$pval, NA, NA, NA, NA, NA, NA, NA))

# Perform trim and fill
taf = trimfill(result)
df <- rbind(df, c("slope_no_blanket_peatlands_trim_and_fill_est_missing_studies", taf$k0, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA))

# Plot trim and fill results
pdf("regr_block_funnel_slope_trim_and_fill.pdf", height = 4, width = 4)
funnel(taf, xlab = "Raw mean difference")
dev.off() 

# Investigate if intercept results are different if weight is based on standard error (how well study data fit a log regression function)
result = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Regr_intercept, sei = Regr_intercept_SE, test = "knha")
result

df <- rbind(df, c("intercept_no_blanket_peatlands_sensitivity_weights_as_study_se", result$b, result$se, result$ci.lb, result$ci.ub, result$k, result$pval, result$tau2, result$I2, result$H2, result$QE, result$QEp, NA, NA))

# Make a funnel plot of effect size vs study variance
pdf("regr_block_funnel_intercept.pdf", height = 4, width = 4)
funnel(result, xlab = "Intercept")
dev.off() 

# Perform Egger's test of funnel plot assymetry
rt = regtest(result)
df <- rbind(df, c("intercept_no_blanket_peatlands_eggers_test_weights_as_study_se", rt$est, NA, rt$ci.lb, rt$ci.ub, NA, rt$pval, NA, NA, NA, NA, NA, NA, NA))

# Trim and fill results
taf = trimfill(result)
df <- rbind(df, c("intercept_no_blanket_peatlands_trim_and_fill_est_missing_studies", taf$k0, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA))

# Make funnel plot with trimmed and filled data
pdf("regr_block_funnel_intercept_trim_and_fill.pdf", height = 4, width = 4)
funnel(taf, xlab = "Raw mean difference")
dev.off() 

# Sensitivity test - remove studies with high risk of bias
# -----------------------------------------------


# Test results when retaining only studies with at least four occurrences of "low risk of bias"
AtLeastFourLowRoB = (rowSums(esd == "Low risk", na.rm = TRUE) > 3) & NoBlanketPeatlands

result = rma(measure = "MD", data = esd[AtLeastFourLowRoB,], yi = Regr_slope, sei = Regr_slope_SE, test = "knha", weights = True_reps)
result

df <- rbind(df, c("slope_no_blanket_peatlands_sensitivity_min_four_low_rob", result$b, result$se, result$ci.lb, result$ci.ub, result$k, result$pval, result$tau2, result$I2, result$H2, result$QE, result$QEp, NA, NA))

result = rma(measure = "MD", data = esd[AtLeastFourLowRoB,], yi = Regr_intercept, sei = Regr_intercept_SE, test = "knha", weights = True_reps)
result

df <- rbind(df, c("intercept_no_blanket_peatlands_sensitivity_min_four_low_rob", result$b, result$se, result$ci.lb, result$ci.ub, result$k, result$pval, result$tau2, result$I2, result$H2, result$QE, result$QEp, NA, NA))


# Sensitivity test - test influence of sampling distance from ditch
# -----------------------------------------------

# Investigate the possible sensitivity to maximum sampled distance
result = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Regr_slope, sei = Regr_slope_SE, weights = True_reps, mods = ~ Max_dist_for_gwl_sampling)
result

df <- rbind(df, c("slope_no_blanket_peatlands_sensitivity_max_dist_for_gwl_sampling", result$b[2], result$se[2], result$ci.lb[2], result$ci.ub[2], result$k, result$pval[2], result$tau2, result$I2, result$H2, result$QE, result$QEp, result$QM, result$QMp))

result = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Regr_intercept, sei = Regr_intercept_SE, weights = True_reps, mods = ~ Max_dist_for_gwl_sampling)
result

df <- rbind(df, c("intercept_no_blanket_peatlands_sensitivity_max_dist_for_gwl_sampling", result$b[2], result$se[2], result$ci.lb[2], result$ci.ub[2], result$k, result$pval[2], result$tau2, result$I2, result$H2, result$QE, result$QEp, result$QM, result$QMp))

# Sensitivity test - include only studies that measure absolute height against common datum and not vs ground surface level
# -----------------------------------------------
FixedRefLevel = esd$"Groundwater level reference point" == "Fixed point or common datum"

result = rma(measure = "MD", data = esd[FixedRefLevel,], yi = Regr_slope, sei = Regr_slope_SE, test = "knha", weights = True_reps)
result

result = rma(measure = "MD", data = esd[FixedRefLevel,], yi = Regr_intercept, sei = Regr_intercept_SE, test = "knha", weights = True_reps)
result


# Test the factor as a whole
result = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Regr_slope, sei = Regr_slope_SE, mods = ~ factor(Gwl_ref_point), test = "knha", weights = True_reps)
result 

df <- rbind(df, c("slope_no_blanket_peatlands_sensitivity_gwl_ref_point", result$b[2], result$se[2], result$ci.lb[2], result$ci.ub[2], result$k, result$pval[2], result$tau2, result$I2, result$H2, result$QE, result$QEp, result$QM, result$QMp))
 
# Plot results
pdf("regr_block_mod_slope_gwl_ref_point.pdf", height = 4, width = 8)
result = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Regr_slope, sei = Regr_slope_SE, mods = ~ factor(Gwl_ref_point) - 1, test = "knha", weights = True_reps)
forest(result$b, sei = result$se, header = c("GWL reference point", "Slope [95% CI]"),
		slab = str_replace(row.names(result$b), "factor\\(Gwl_ref_point\\)", ""),
		ilab = colSums(result$X), ilab.xpos = -18,
		xlim = c(-35, 12), 
		digits = c(decimals_rows, decimals_axis),
		xlab = "Slope", psize = 1
)
par(font=2)
text(-18, 4, "n")
dev.off()

result = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Regr_intercept, sei = Regr_intercept_SE, mods = ~ factor(Gwl_ref_point), test = "knha", weights = True_reps)
result 

df <- rbind(df, c("intercept_no_blanket_peatlands_sensitivity_gwl_ref_point", result$b[2], result$se[2], result$ci.lb[2], result$ci.ub[2], result$k, result$pval[2], result$tau2, result$I2, result$H2, result$QE, result$QEp, result$QM, result$QMp))


# Sensitivity test - test influence of replication type
# -----------------------------------------------
result = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Regr_slope, sei = Regr_slope_SE, weights = True_reps, mods = ~ Regr_slope_Replication)
result

df <- rbind(df, c("slope_no_blanket_peatlands_sensitivity_replication_type", result$b[2], result$se[2], result$ci.lb[2], result$ci.ub[2], result$k, result$pval[2], result$tau2, result$I2, result$H2, result$QE, result$QEp, result$QM, result$QMp))

result = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Regr_intercept, sei = Regr_intercept_SE, weights = True_reps, mods = ~ Max_dist_for_gwl_sampling)
result

df <- rbind(df, c("intercept_no_blanket_peatlands_sensitivity_replication_type", result$b[2], result$se[2], result$ci.lb[2], result$ci.ub[2], result$k, result$pval[2], result$tau2, result$I2, result$H2, result$QE, result$QEp, result$QM, result$QMp))


# Sensitivity - confirm blanket peatlands as group moderator
# -----------------------------------------
# Confirm whether blanket peatlands are different as a group
names(esd)[names(esd) == "Blanket peatland"] <- "Blanket_peatland"
esd$Blanket_peatland[is.na(esd$Blanket_peatland)] = "No"
result = rma(measure = "MD", data = esd, yi = Regr_slope, sei = Regr_slope_SE, weights = True_reps, mods = ~ factor(Blanket_peatland))
result

# Save results to disk
# ---------------------
write.xlsx(df, paste(output_dir, "meta-analysis_results_regr_block.xlsx", sep = "/"), dec = ",")

