# Run meta-analysis of restoration of wetlands

require(metafor)
library(openxlsx)
library(stringr)

output_dir = "C:/wetlands/restore"
setwd(output_dir)

# Function definitions
# ----------------------
mlabfun <- function(text, res) {
   paste(text, 
#   " (Q =", (formatC(res$QE, digits=2, format="f")),
#  ", df =", (res$k - res$p),
#   ", I^2 =", (formatC(res$I2, digits=1, format="f")), "%, ",
#   "tau^2 =", (formatC(res$tau2, digits=2, format="f")),
#    ")"
""
)}

# Constants
# ----------------------

# No of decimal digits for forest plot rows
decimals_rows = 0
# No of decimal digits for forest plot axis tick labels
decimals_axis = 0

# Start of program
# ----------------------

# Load data from combined effect size file
esd <- read.xlsx("C:/wetlands/Additional file 5.xlsx")

# Update header
names(esd) <- esd[1,]

# Drop first row of data (the second row of header information)
esd <- esd[-c(1), ]

# Drop treatment categories that are not restoration or creation
esd <- esd[(esd$"Drainage/Restoration/Creation" == "Restoration" | esd$"Drainage/Restoration/Creation" == "Creation"),]

# Drop rows without treatment id (not included in meta-analysis)
esd <- esd[!(is.na(esd$"Raw mean difference Treatment ID")),]

# Drop one study for which the wetland types are not reported, and that cannot be included in any group
esd <- esd[!(esd$"Covidence id" == "#10532"),] # Engman 2020

# Set data types to numerical values for some columns we need in the analysis
esd$"Year" <- as.numeric(esd$"Year")
esd$"Raw mean difference GWL" <- as.numeric(esd$"Raw mean difference GWL")
esd$"Raw mean difference GWL.SE" <- as.numeric(esd$"Raw mean difference GWL.SE")
esd$"Raw mean difference GWL.N" <- as.numeric(esd$"Raw mean difference GWL.N")
esd$"True replications (intervention level, count only intervention sites, not control)" <- as.numeric(esd$"True replications (intervention level, count only intervention sites, not control)")
esd$"Average or estimated ditch spacing (m)" <- as.numeric(esd$"Average or estimated ditch spacing (m)")
esd$"Average peat depth (cm)" <- as.numeric(esd$"Average peat depth (cm)")
esd$"Time since intervetion (min, yrs)" <- as.numeric(esd$"Time since intervetion (min, yrs)") 
esd$"Time since intervetion (max, yrs)" <- as.numeric(esd$"Time since intervetion (max, yrs)")
esd$"Intervention magnitude (depth/height in cm)" <- as.numeric(esd$"Intervention magnitude (depth/height in cm)")
esd$"Slope (degrees)" <- as.numeric(esd$"Slope (degrees)")
esd$"Maximum distance of gwl measurements (m)" <- as.numeric(esd$"Maximum distance of gwl measurements (m)")

# Rename a few columns we need to work with in metafor (which can't handle column names in quotes)
names(esd)[names(esd) == "Short ref"] <- "Short_ref"
names(esd)[names(esd) == "Raw mean difference Treatment ID"] <- "Treatment_ID"
names(esd)[names(esd) == "Raw mean difference GWL"] <- "Gwl_diff"
names(esd)[names(esd) == "Raw mean difference GWL.SE"] <- "Gwl_diff_SE"
names(esd)[names(esd) == "Raw mean difference GWL.N"] <- "Gwl_diff_N"
names(esd)[names(esd) == "Raw mean difference GWL.Replication"] <- "Gwl_diff_Replication"
names(esd)[names(esd) == "Wetland type"] <- "Wetland_type"
names(esd)[names(esd) == "Climate zone"] <- "Climate_zone"
names(esd)[names(esd) == "Average peat depth (cm)"] <- "Peat_depth"
names(esd)[names(esd) == "Average or estimated ditch spacing (m)"] <- "Ditch_spacing"
names(esd)[names(esd) == "Study design"] <- "Study_design"
names(esd)[names(esd) == "True replications (intervention level, count only intervention sites, not control)"] <- "True_reps"
names(esd)[names(esd) == "Time since intervetion (min, yrs)"] <- "Time_since_intervention_min"
names(esd)[names(esd) == "Time since intervetion (max, yrs)"] <- "Time_since_intervention_max"
names(esd)[names(esd) == "Short ref with extra info"] <- "Short_ref_info"
names(esd)[names(esd) == "Underlying soil type"] <- "Underlying_soil"
names(esd)[names(esd) == "Original order"] <- "Original_order"
names(esd)[names(esd) == "Intervention magnitude (depth/height in cm)"] <- "Intervention_magnitude"
names(esd)[names(esd) == "Slope (degrees)"] <- "Slope"
names(esd)[names(esd) == "Maximum distance of gwl measurements (m)"] <- "Max_dist_for_gwl_sampling"
names(esd)[names(esd) == "Confined/mirrored (by next ditch) or open-ended transect"] <- "Transect_type"
names(esd)[names(esd) == "Type of intervention (primary)"] <- "Intervention_type_primary"
names(esd)[names(esd) == "Groundwater level reference point"] <- "Gwl_ref_point"

# Make a new column with average time since intervention
esd$Time_since_intervention_avg <- rowMeans(esd[,c("Time_since_intervention_min", "Time_since_intervention_max")], na.rm=TRUE)

# Adjustments to data when collapsing multiple rows per study to a single row
# ---------------------------------------------------------------------------

# Aggregate certain numeric values for multi-row studies
agg = aggregate(Ditch_spacing ~ Treatment_ID, esd, FUN = mean)
esd$Ditch_spacing <- agg[match(esd$Treatment_ID, agg$Treatment_ID), 2]

agg = aggregate(Peat_depth ~ Treatment_ID, esd, FUN = mean)
esd$Peat_depth <- agg[match(esd$Treatment_ID, agg$Treatment_ID), 2]

# For true replicates, update the "True reps" column with the actual no of replicates used for each treatment code
esd$True_reps[esd$Gwl_diff_Replication == "TRUE"] <- esd$Gwl_diff_N[esd$Gwl_diff_Replication == "TRUE"]

# Keep only one row per treatment ID
esd <- esd[!duplicated(esd[,c("Treatment_ID")]),]

# With only one data row remaining per treatment, the wetland type needs to be adjusted for studies that span over multiple wetland types
# with the type was explicitly noted on each row in the study (Bog, Fen, etc) but the treatment code is the same for several rows.
esd$Wetland_type[esd$"Covidence id" == "#10375"] <- "Unspecified peatland" # Bonsel 2011
esd$Wetland_type[esd$"Covidence id" == "#10367"] <- "Unspecified peatland" # Haapalehto 2011
esd$Wetland_type[esd$"Covidence id" == "#10394"] <- "Unspecified peatland" # Strack 2016

# Sort by column Wetland_type, then Short_ref, then first col (original row number in metadata table)
esd <- esd[with(esd, order(Wetland_type, Short_ref_info, Original_order)), ]

# Perform a meta-analysis of gwl diff
# --------------------------------------------
# Calculate RE model based on underlying sample size (number of true replications) weights = True_reps
result = rma(measure = "MD", data = esd, yi = Gwl_diff, sei = Gwl_diff_SE, slab = esd$Short_ref, test = "knha", weights = True_reps)
result

# Set up data frame to save meta-analysis results
df <- data.frame(value = c("gwl_diff_main_all"), estimate = c(result$b), SE = c(result$se), ci.lb = c(result$ci.lb), ci.ub = c(result$ci.ub), k = c(result$k), pval = c(result$pval), tau2 = c(result$tau2), I2 = c(result$I2), H2 = c(result$H2), QE = c(result$QE), QEp = c(result$QEp), QM = c(NA), QMp = c(NA))

# Plotting 
# --------------------------------------------
# Count rows for each wetland type
# Needs to be adjusted for different number of groups
group_rowcounts = table(esd$Wetland_type)

# We want the cumulative no of rows in reverse alphabetical order for plotting (unspecified peatland, mire, fen, bog)
group_cum_rowcounts = cumsum(rev(group_rowcounts))

# Start rows (counting from bottom end of table) for the wetland types
group_start_rows = c(3, group_cum_rowcounts[1] + 7, 
				group_cum_rowcounts[2] + 11, 
				group_cum_rowcounts[3] + 15, 
				group_cum_rowcounts[4] + 19)
#				group_cum_rowcounts[5] + 23)

# End rows (counting from bottom end of table) for the wetland types
group_end_rows = c(group_cum_rowcounts[1] + 2, 
			 group_cum_rowcounts[2] + 6, 
			 group_cum_rowcounts[3] + 10, 
			 group_cum_rowcounts[4] + 14,
			 group_cum_rowcounts[5] + 18)
#			 group_cum_rowcounts[6] + 22)

# The final rows on which to plot all data
group_rows = c( #group_end_rows[6]:group_start_rows[6],
		   group_end_rows[5]:group_start_rows[5],
		   group_end_rows[4]:group_start_rows[4], 
		   group_end_rows[3]:group_start_rows[3], 
		   group_end_rows[2]:group_start_rows[2], 
		   group_end_rows[1]:group_start_rows[1] 
) 

# Save plot
pdf("forest_restore_groups.pdf", height = 12)

# Print a forest plot of slopes
forest(result, slab = esd$Short_ref, #_info, 
	header = c("Author and year", "Raw mean difference [95% CI]"), 
 	ilab = esd$True_reps, ilab.xpos = -90,
	cex = 0.75,
	rows = group_rows, ylim = c(-1, max(group_end_rows) + 4), 
	# mlab = mlabfun("RE Model, all studies", result),
	digits = c(decimals_rows, decimals_axis),
	xlab = "Change in groundwater level (cm)" #, xlim = c(-95, 70)	
	)
op <- par(cex=.75, font=2)
text(-90, max(group_end_rows) + 3, "Wetlands")
text(-90, -1, sum(as.numeric(result$weights)), font = 1)

par(font = 4)
text(-265, group_end_rows + 1, pos = 4, rownames(rev(group_rowcounts)))
par(op)

# Fit random-effects model in the subgroups
res.b <- rma(measure = "MD", data = esd, subset = (Wetland_type == "Bog"), yi = Gwl_diff, sei = Gwl_diff_SE, test = "knha", weights = True_reps)
res.f <- rma(measure = "MD", data = esd, subset = (Wetland_type == "Fen"), yi = Gwl_diff, sei = Gwl_diff_SE, test = "knha", weights = True_reps)
res.l <- rma(measure = "MD", data = esd, subset = (Wetland_type == "Limnic shore wetland"), yi = Gwl_diff, sei = Gwl_diff_SE, test = "knha", weights = True_reps)
res.m <- rma(measure = "MD", data = esd, subset = (Wetland_type == "Mire"), yi = Gwl_diff, sei = Gwl_diff_SE, test = "knha", weights = True_reps)
res.u <- rma(measure = "MD", data = esd, subset = (Wetland_type == "Unspecified peatland"), yi = Gwl_diff, sei = Gwl_diff_SE, test = "knha", weights = True_reps)

# Add summary polygons for the subgroups
addpoly(res.b, row = group_start_rows[5] -1.5, cex = 0.75, mlab = mlabfun("RE Model for subgroup", res.b), digits = decimals_rows)
addpoly(res.f, row = group_start_rows[4] -1.5, cex = 0.75, mlab = mlabfun("RE Model for subgroup", res.f), digits = decimals_rows)
addpoly(res.l, row = group_start_rows[3] -1.5, cex = 0.75, mlab = mlabfun("RE Model for subgroup", res.l), digits = decimals_rows)
addpoly(res.m, row = group_start_rows[2] -1.5, cex = 0.75, mlab = mlabfun("RE Model for subgroup", res.m), digits = decimals_rows)
addpoly(res.u, row = group_start_rows[1] -1.5, cex = 0.75, mlab = mlabfun("RE Model for subgroup", res.u), digits = decimals_rows)

text(-90, group_start_rows[5] - 1.5, sum(as.numeric(res.b$weights)), font = 1, cex = 0.75)
text(-90, group_start_rows[4] - 1.5, sum(as.numeric(res.f$weights)), font = 1, cex = 0.75)
text(-90, group_start_rows[3] - 1.5, sum(as.numeric(res.l$weights)), font = 1, cex = 0.75)
text(-90, group_start_rows[2] - 1.5, sum(as.numeric(res.m$weights)), font = 1, cex = 0.75)
text(-90, group_start_rows[1] - 1.5, sum(as.numeric(res.u$weights)), font = 1, cex = 0.75)

# Close graphics
dev.off() 

# Add results to df for later export
df <- rbind(df, c("gwl_diff_main_bog", res.b$b, res.b$se, res.b$ci.lb, res.b$ci.ub, res.b$k, res.b$pval, res.b$tau2, res.b$I2, res.b$H2, res.b$QE, res.b$QEp, NA, NA))
df <- rbind(df, c("gwl_diff_main_fen", res.f$b, res.f$se, res.f$ci.lb, res.f$ci.ub, res.f$k, res.f$pval, res.f$tau2, res.f$I2, res.f$H2, res.f$QE, res.f$QEp, NA, NA))
df <- rbind(df, c("gwl_diff_main_limnic", res.l$b, res.l$se, res.l$ci.lb, res.l$ci.ub, res.l$k, res.l$pval, res.l$tau2, res.l$I2, res.l$H2, res.l$QE, res.l$QEp, NA, NA))
df <- rbind(df, c("gwl_diff_main_mire", res.m$b, res.m$se, res.m$ci.lb, res.m$ci.ub, res.m$k, res.m$pval, res.m$tau2, res.m$I2, res.m$H2, res.m$QE, res.m$QEp, NA, NA))
df <- rbind(df, c("gwl_diff_main_unspec", res.u$b, res.u$se, res.u$ci.lb, res.u$ci.ub, res.u$k, res.u$pval, res.u$tau2, res.u$I2, res.u$H2, res.u$QE, res.u$QEp, NA, NA))




# Handling blanket peatlands, and peatlands only
# -------------------
NoBlanketPeatlands = is.na(esd$"Blanket peatland") # & (esd$Wetland_type %in% c("Bog", "Fen", "Mire", "Unspecified peatland", "Other", "Limnic shore wetland"))

result = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Gwl_diff, sei = Gwl_diff_SE, test = "knha", weights = True_reps)
result

# Add results to df for later export
df <- rbind(df, c("gwl_diff_no_blanket_peatlands", result$b, result$se, result$ci.lb, result$ci.ub, result$k, result$pval, result$tau2, result$I2, result$H2, result$QE, result$QEp, NA, NA))

# Plotting of all wetlands except blanket peatlands
# --------------------------------------------
# Count rows for each wetland type
# Needs to be adjusted for different number of groups
group_rowcounts = table(esd[NoBlanketPeatlands,]$Wetland_type)

# We want the cumulative no of rows in reverse alphabetical order for plotting (unspecified peatland, mire, fen, bog)
group_cum_rowcounts = cumsum(rev(group_rowcounts))

# Start rows (counting from bottom end of table) for the wetland types
group_start_rows = c(3, group_cum_rowcounts[1] + 7, 
				group_cum_rowcounts[2] + 11, 
				group_cum_rowcounts[3] + 15, 
				group_cum_rowcounts[4] + 19)
#				group_cum_rowcounts[5] + 23)

# End rows (counting from bottom end of table) for the wetland types
group_end_rows = c(group_cum_rowcounts[1] + 2, 
			 group_cum_rowcounts[2] + 6, 
			 group_cum_rowcounts[3] + 10, 
			 group_cum_rowcounts[4] + 14,
			 group_cum_rowcounts[5] + 18)
#			 group_cum_rowcounts[6] + 22)

# The final rows on which to plot all data
group_rows = c( #group_end_rows[6]:group_start_rows[6],
		   group_end_rows[5]:group_start_rows[5],
		   group_end_rows[4]:group_start_rows[4], 
		   group_end_rows[3]:group_start_rows[3], 
		   group_end_rows[2]:group_start_rows[2], 
		   group_end_rows[1]:group_start_rows[1] 
) 

# Save plot
pdf("forest_restore_groups_no_blanket_peatlands.pdf", height = 11)

# Print a forest plot of slopes
forest(result, slab = esd[NoBlanketPeatlands,]$Short_ref, #_info, 
	header = c("Author and year", "Raw mean difference [95% CI]"), 
 	ilab = esd[NoBlanketPeatlands,]$True_reps, ilab.xpos = -115,
	cex = 0.75,
	rows = group_rows, ylim = c(-1, max(group_end_rows) + 4), 
	# mlab = mlabfun("RE Model, all studies", result),
	digits = c(decimals_rows, decimals_axis),
	xlab = "Change in groundwater level (cm)" #, xlim = c(-95, 70)	
	)
op <- par(cex=.75, font=2)
text(-115, max(group_end_rows) + 3, "Wetlands")

par(font = 4)
text(-265, group_end_rows + 1, pos = 4, rownames(rev(group_rowcounts)))
par(op)

# Fit random-effects model in the subgroups
res.b <- rma(measure = "MD", data = esd[NoBlanketPeatlands,], subset = (Wetland_type == "Bog"), yi = Gwl_diff, sei = Gwl_diff_SE, test = "knha", weights = True_reps)
res.f <- rma(measure = "MD", data = esd[NoBlanketPeatlands,], subset = (Wetland_type == "Fen"), yi = Gwl_diff, sei = Gwl_diff_SE, test = "knha", weights = True_reps)
res.l <- rma(measure = "MD", data = esd[NoBlanketPeatlands,], subset = (Wetland_type == "Limnic shore wetland"), yi = Gwl_diff, sei = Gwl_diff_SE, test = "knha", weights = True_reps)
res.m <- rma(measure = "MD", data = esd[NoBlanketPeatlands,], subset = (Wetland_type == "Mire"), yi = Gwl_diff, sei = Gwl_diff_SE, test = "knha", weights = True_reps)
res.u <- rma(measure = "MD", data = esd[NoBlanketPeatlands,], subset = (Wetland_type == "Unspecified peatland"), yi = Gwl_diff, sei = Gwl_diff_SE, test = "knha", weights = True_reps)

# Add summary polygons for the subgroups
addpoly(res.b, row = group_start_rows[5] -1.5, cex = 0.75, mlab = mlabfun("RE Model for subgroup", res.b), digits = decimals_rows)
addpoly(res.f, row = group_start_rows[4] -1.5, cex = 0.75, mlab = mlabfun("RE Model for subgroup", res.f), digits = decimals_rows)
addpoly(res.l, row = group_start_rows[3] -1.5, cex = 0.75, mlab = mlabfun("RE Model for subgroup", res.l), digits = decimals_rows)
addpoly(res.m, row = group_start_rows[2] -1.5, cex = 0.75, mlab = mlabfun("RE Model for subgroup", res.m), digits = decimals_rows)
addpoly(res.u, row = group_start_rows[1] -1.5, cex = 0.75, mlab = mlabfun("RE Model for subgroup", res.u), digits = decimals_rows)

# Close graphics
dev.off() 

# Add results to df for later export
df <- rbind(df, c("gwl_diff_no_blanket_peatlands_bog", res.b$b, res.b$se, res.b$ci.lb, res.b$ci.ub, res.b$k, res.b$pval, res.b$tau2, res.b$I2, res.b$H2, res.b$QE, res.b$QEp, NA, NA))
df <- rbind(df, c("gwl_diff_no_blanket_peatlands_fen", res.f$b, res.f$se, res.f$ci.lb, res.f$ci.ub, res.f$k, res.f$pval, res.f$tau2, res.f$I2, res.f$H2, res.f$QE, res.f$QEp, NA, NA))
df <- rbind(df, c("gwl_diff_no_blanket_peatlands_limnic", res.l$b, res.l$se, res.l$ci.lb, res.l$ci.ub, res.l$k, res.l$pval, res.l$tau2, res.l$I2, res.l$H2, res.l$QE, res.l$QEp, NA, NA))
df <- rbind(df, c("gwl_diff_no_blanket_peatlands_mire", res.m$b, res.m$se, res.m$ci.lb, res.m$ci.ub, res.m$k, res.m$pval, res.m$tau2, res.m$I2, res.m$H2, res.m$QE, res.m$QEp, NA, NA))
df <- rbind(df, c("gwl_diff_no_blanket_peatlands_unspec", res.u$b, res.u$se, res.u$ci.lb, res.u$ci.ub, res.u$k, res.u$pval, res.u$tau2, res.u$I2, res.u$H2, res.u$QE, res.u$QEp, NA, NA))

# Now look at only blanket peatlands
# ---------------------------------

# OnlyBlanketPeatlands = esd$"Blanket peatland" == "Yes"
OnlyBlanketPeatlands = !is.na(esd$"Blanket peatland")

result = rma(measure = "MD", data = esd[OnlyBlanketPeatlands ,], yi = Gwl_diff, sei = Gwl_diff_SE, test = "knha", weights = True_reps)
result

# Add results to df for later export
df <- rbind(df, c("gwl_diff_only_blanket_peatlands", result$b, result$se, result$ci.lb, result$ci.ub, result$k, result$pval, result$tau2, result$I2, result$H2, result$QE, result$QEp, NA, NA))

# Plotting of only the blanket peatlands
# --------------------------------------------
# Count rows for each wetland type
# Needs to be adjusted for different number of groups
group_rowcounts = table(esd[OnlyBlanketPeatlands,]$Wetland_type)

# We want the cumulative no of rows in reverse alphabetical order for plotting (unspecified peatland, mire, fen, bog)
group_cum_rowcounts = cumsum(rev(group_rowcounts))

# Start rows (counting from bottom end of table) for the wetland types
group_start_rows = c(3, group_cum_rowcounts[1] + 7, 
				group_cum_rowcounts[2] + 11 
#				group_cum_rowcounts[3] + 15, 
#				group_cum_rowcounts[4] + 19,
#				group_cum_rowcounts[5] + 23
)

# End rows (counting from bottom end of table) for the wetland types
group_end_rows = c(group_cum_rowcounts[1] + 2, 
			 group_cum_rowcounts[2] + 6, 
			 group_cum_rowcounts[3] + 10 
#			 group_cum_rowcounts[4] + 14,
#			 group_cum_rowcounts[5] + 18,
#			 group_cum_rowcounts[6] + 22
)

# The final rows on which to plot all data
group_rows = c(# group_end_rows[6]:group_start_rows[6],
		   # group_end_rows[5]:group_start_rows[5],
		   # group_end_rows[4]:group_start_rows[4], 
		   group_end_rows[3]:group_start_rows[3], 
		   group_end_rows[2]:group_start_rows[2], 
		   group_end_rows[1]:group_start_rows[1] 
) 

# Save plot
pdf("forest_restore_groups_only_blanket_peatlands.pdf", height = 6)

# Print a forest plot of slopes
forest(result, slab = esd[OnlyBlanketPeatlands,]$Short_ref, #_info, 
	header = c("Author and year", "Raw mean difference [95% CI]"), 
 	ilab = esd[OnlyBlanketPeatlands,]$True_reps, ilab.xpos = -115,
	cex = 0.75,
	rows = group_rows, ylim = c(-1, max(group_end_rows) + 4), 
	# mlab = mlabfun("RE Model, all studies", result),
	digits = c(decimals_rows, decimals_axis),
	xlab = "Change in groundwater level (cm)" #, xlim = c(-95, 70)	
	)
op <- par(cex=.75, font=2)
text(-115, max(group_end_rows) + 3, "Wetlands")

par(font = 4)
# text(-450, group_end_rows + 1, pos = 4, rownames(rev(group_rowcounts)))
text(-77, group_end_rows + 1, pos = 4, rownames(rev(group_rowcounts)))
par(op)

# Fit random-effects model in the subgroups
res.b <- rma(measure = "MD", data = esd[OnlyBlanketPeatlands,], subset = (Wetland_type == "Bog"), yi = Gwl_diff, sei = Gwl_diff_SE, test = "knha", weights = True_reps)
# res.f <- rma(measure = "MD", data = esd[OnlyBlanketPeatlands,], subset = (Wetland_type == "Fen"), yi = Gwl_diff, sei = Gwl_diff_SE, test = "knha", weights = True_reps)
# res.l <- rma(measure = "MD", data = esd[OnlyBlanketPeatlands,], subset = (Wetland_type == "Limnic shore wetland"), yi = Gwl_diff, sei = Gwl_diff_SE, test = "knha", weights = True_reps)
res.m <- rma(measure = "MD", data = esd[OnlyBlanketPeatlands,], subset = (Wetland_type == "Mire"), yi = Gwl_diff, sei = Gwl_diff_SE, test = "knha", weights = True_reps)
res.u <- rma(measure = "MD", data = esd[OnlyBlanketPeatlands,], subset = (Wetland_type == "Unspecified peatland"), yi = Gwl_diff, sei = Gwl_diff_SE, test = "knha", weights = True_reps)

# Add summary polygons for the subgroups
addpoly(res.b, row = group_start_rows[3] -1.5, cex = 0.75, mlab = mlabfun("RE Model for subgroup", res.b), digits = decimals_rows)
# addpoly(res.f, row = group_start_rows[4] -1.5, cex = 0.75, mlab = mlabfun("RE Model for subgroup", res.f), digits = decimals_rows)
# addpoly(res.l, row = group_start_rows[3] -1.5, cex = 0.75, mlab = mlabfun("RE Model for subgroup", res.l), digits = decimals_rows)
addpoly(res.m, row = group_start_rows[2] -1.5, cex = 0.75, mlab = mlabfun("RE Model for subgroup", res.m), digits = decimals_rows)
addpoly(res.u, row = group_start_rows[1] -1.5, cex = 0.75, mlab = mlabfun("RE Model for subgroup", res.u), digits = decimals_rows)

# Close graphics
dev.off() 

# Add results to df for later export
df <- rbind(df, c("gwl_diff_only_blanket_peatlands_bog", res.b$b, res.b$se, res.b$ci.lb, res.b$ci.ub, res.b$k, res.b$pval, res.b$tau2, res.b$I2, res.b$H2, res.b$QE, res.b$QEp, NA, NA))
# df <- rbind(df, c("gwl_diff_only_blanket_peatlands_fen", res.f$b, res.f$se, res.f$ci.lb, res.f$ci.ub, res.f$k, res.f$pval, res.f$tau2, res.f$I2, res.f$H2, res.f$QE, res.f$QEp, NA, NA))
# df <- rbind(df, c("gwl_diff_only_blanket_peatlands_limnic", res.l$b, res.l$se, res.l$ci.lb, res.l$ci.ub, res.l$k, res.l$pval, res.l$tau2, res.l$I2, res.l$H2, res.l$QE, res.l$QEp, NA, NA))
df <- rbind(df, c("gwl_diff_only_blanket_peatlands_mire", res.m$b, res.m$se, res.m$ci.lb, res.m$ci.ub, res.m$k, res.m$pval, res.m$tau2, res.m$I2, res.m$H2, res.m$QE, res.m$QEp, NA, NA))
df <- rbind(df, c("gwl_diff_only_blanket_peatlands_unspec", res.u$b, res.u$se, res.u$ci.lb, res.u$ci.ub, res.u$k, res.u$pval, res.u$tau2, res.u$I2, res.u$H2, res.u$QE, res.u$QEp, NA, NA))


# Summary effect across peatland groups, with and without blanket peatlands
# ----------------------

AllPeatlandsIncludingBlanketPeatlands = (esd$Wetland_type %in% c("Bog", "Fen", "Mire", "Unspecified peatland"))

result = rma(measure = "MD", data = esd[AllPeatlandsIncludingBlanketPeatlands,], yi = Gwl_diff, sei = Gwl_diff_SE, test = "knha", weights = True_reps)
result

# Add results to df for later export
df <- rbind(df, c("gwl_diff_all_peatlands_including_blanket_peatlands", result$b, result$se, result$ci.lb, result$ci.ub, result$k, result$pval, result$tau2, result$I2, result$H2, result$QE, result$QEp, NA, NA))


AllPeatlandsExcludingBlanketPeatlands = is.na(esd$"Blanket peatland") & (esd$Wetland_type %in% c("Bog", "Fen", "Mire", "Unspecified peatland"))

result = rma(measure = "MD", data = esd[AllPeatlandsExcludingBlanketPeatlands ,], yi = Gwl_diff, sei = Gwl_diff_SE, test = "knha", weights = True_reps)
result

# Add results to df for later export
df <- rbind(df, c("gwl_diff_all_peatlands_excluding_blanket_peatlands", result$b, result$se, result$ci.lb, result$ci.ub, result$k, result$pval, result$tau2, result$I2, result$H2, result$QE, result$QEp, NA, NA))


# Various variations
# -------------------

# Cumulative forest plot
result = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Gwl_diff, sei = Gwl_diff_SE, test = "knha", weights = True_reps, slab = Short_ref)
tmp <- cumul(result, order=esd[NoBlanketPeatlands,]$"Year")

# Save plot
pdf("forest_restore_cumulative_effect_size_estimate.pdf", height = 10)

# Print a forest plot of cumulative effect size
forest(tmp, 
	header = c("Author and year", "Raw mean difference [95% CI]"), 
	digits = c(decimals_rows, decimals_axis),
	cex = 0.75,	xlab = "Change in groundwater level (cm)"
	)
# Close graphics
dev.off() 

# In the other meta-analyses the "no blanket peatlands" group does not include any limnic shore wetlands, only peatlands
# For remaining analyses do the same here
NoBlanketPeatlands = AllPeatlandsExcludingBlanketPeatlands 

# Tests of moderators
# -------------------

# Investigate the possible influence of wetland type as moderator
res_wetland = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Gwl_diff, sei = Gwl_diff_SE, test = "knha", mods = ~factor(Wetland_type) - 1, weights = True_reps)
res_wetland

# Save plot
pdf("restore_mod_wetland_type.pdf", height = 4)

forest(res_wetland$b, sei = res_wetland$se, header = c("Wetland type", "Raw mean difference [95% CI]"),
	slab = str_replace(row.names(res_wetland$b), "factor\\(Wetland_type\\)", ""),
	ilab = colSums(res_wetland$X), ilab.xpos = -38,
	digits = c(decimals_rows, decimals_axis),
	xlab = "Change in groundwater level (cm)", psize = 1

)
par(font=2)
text(-38, 6, "n")
dev.off() 

# Test the wetland type factor as a whole
result = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Gwl_diff, sei = Gwl_diff_SE, test = "knha", mods = ~factor(Wetland_type), weights = True_reps)
result

df <- rbind(df, c("gwl_diff_no_blanket_peatlands_moderator_wetland_type", result$b[2], result$se[2], result$ci.lb[2], result$ci.ub[2], result$k, result$pval[2], result$tau2, result$I2, result$H2, result$QE, result$QEp, result$QM, result$QMp))

# Investigate the possible influence of peat depth as moderator
result = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Gwl_diff, sei = Gwl_diff_SE, test = "knha", mods = ~ Peat_depth, weights = True_reps)
result 

df <- rbind(df, c("gwl_diff_no_blanket_peatlands_moderator_peat_depth", result$b[2], result$se[2], result$ci.lb[2], result$ci.ub[2], result$k, result$pval[2], result$tau2, result$I2, result$H2, result$QE, result$QEp, result$QM, result$QMp))

# Investigate the possible influence of time since intervention as moderator
result = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Gwl_diff, sei = Gwl_diff_SE, test = "knha", mods = ~ Time_since_intervention_avg, weights = True_reps)
result

df <- rbind(df, c("gwl_diff_no_blanket_peatlands_moderator_time_since_intervention", result$b[2], result$se[2], result$ci.lb[2], result$ci.ub[2], result$k, result$pval[2], result$tau2, result$I2, result$H2, result$QE, result$QEp, result$QM, result$QMp))

# Investigate the possible influence of underlying soil type as moderator
# For this test, group all "Till" studies into the same category, otherwise they are too few
esd_soils = data.frame(esd[NoBlanketPeatlands,])
esd_soils$Underlying_soil[esd_soils$Underlying_soil == "Low-permeability till" | esd_soils$Underlying_soil == "Unsorted till"] <- "Till"
# A few other subgroups have just 1 study and are left out
esd_soils <- esd_soils[!(esd_soils$"Underlying_soil" == "Gyttja") & !(esd_soils$"Underlying_soil" == "Karst and sinkhole terrain") & !(esd_soils$"Underlying_soil" == "Silt") & !(esd_soils$"Underlying_soil" == "Volcanic rock"),]

# Check how many studies there are in each category
soil_type_counts = table(esd_soils$Underlying_soil)

res_soiltype = rma(measure = "MD", data = esd_soils, yi = Gwl_diff, sei = Gwl_diff_SE, test = "knha", mods = ~factor(Underlying_soil) - 1, weights = True_reps)
res_soiltype

# Save plot
pdf("restore_mod_soil_type.pdf", height = 4, width = 8)

# Plot soil type moderators
forest(res_soiltype$b, sei = res_soiltype$se, header = c("Underlying soil", "Raw mean difference [95% CI]"), 
				slab = str_replace(row.names(res_soiltype$b), "factor\\(Underlying_soil\\)", ""),
				ilab = as.list(soil_type_counts), ilab.xpos = -75,
				xlim = c(-600, 300), 
				digits = c(decimals_rows, decimals_axis),
				xlab = "Change in groundwater level (cm)", psize = 1

)
par(font=2)
text(-75, dim(soil_type_counts) + 2, "n")
dev.off() 

# Test the soil type factor as a whole
result = rma(measure = "MD", data = esd_soils, yi = Gwl_diff, sei = Gwl_diff_SE, test = "knha", mods = ~ factor(Underlying_soil), weights = True_reps)
result

df <- rbind(df, c("gwl_diff_no_blanket_peatlands_moderator_soil_type", result$b[1], result$se[1], result$ci.lb[1], result$ci.ub[1], result$k, result$pval[1], result$tau2, result$I2, result$H2, result$QE, result$QEp, result$QM, result$QMp))

# Investigate the possible influence of intervention magnitude as moderator 
result = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Gwl_diff, sei = Gwl_diff_SE, test = "knha", weights = True_reps, mods = ~ Intervention_magnitude)
result

df <- rbind(df, c("gwl_diff_no_blanket_peatlands_moderator_intervention_magnitude", result$b[2], result$se[2], result$ci.lb[2], result$ci.ub[2], result$k, result$pval[2], result$tau2, result$I2, result$H2, result$QE, result$QEp, result$QM, result$QMp))

pdf("restore_mod_metareg_intervention_magnitude.pdf", height = 5, width = 5)
regplot(result, mod = "Intervention_magnitude", xlim=c(0,250), predlim=c(0,250), xlab="Intervention magnitude (cm)", ylab = "Change in groundwater level (cm)", legend = TRUE)
dev.off() 

# Sensitivity test for intervention magnitude, exclude two studies with very large magnitudes
result = rma(measure = "MD", data = esd[NoBlanketPeatlands & esd$Intervention_magnitude < 200,], yi = Gwl_diff, sei = Gwl_diff_SE, test = "knha", weights = True_reps, mods = ~ Intervention_magnitude)
result

df <- rbind(df, c("gwl_diff_no_blanket_peatlands_moderator_intervention_magnitude_below_200_only", result$b[2], result$se[2], result$ci.lb[2], result$ci.ub[2], result$k, result$pval[2], result$tau2, result$I2, result$H2, result$QE, result$QEp, result$QM, result$QMp))

# Investigate the possible influence of intervention magnitude as moderator, for peatlands that are not blanket peatlands only
result = rma(measure = "MD", data = esd[AllPeatlandsExcludingBlanketPeatlands,], yi = Gwl_diff, sei = Gwl_diff_SE, test = "knha", weights = True_reps, mods = ~ Intervention_magnitude)
result

pdf("restore_mod_metareg_intervention_magnitude_all_peatlands_excluding_blanket_peatlands.pdf", height = 5, width = 5)
regplot(result, mod = "Intervention_magnitude", xlim=c(0,250), predlim=c(0,250), xlab="Intervention magnitude (cm)", ylab = "Change in groundwater level (cm)", legend = TRUE)
dev.off() 

df <- rbind(df, c("gwl_diff_all_peatlands_excluding_blanket_peatlands_moderator_intervention_magnitude", result$b[2], result$se[2], result$ci.lb[2], result$ci.ub[2], result$k, result$pval[2], result$tau2, result$I2, result$H2, result$QE, result$QEp, result$QM, result$QMp))

# Investigate the possible influence of ditch spacing as moderator 
result = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Gwl_diff, sei = Gwl_diff_SE, test = "knha", weights = True_reps, mods = ~ Ditch_spacing)
result

df <- rbind(df, c("gwl_diff_no_blanket_peatlands_moderator_ditch_spacing", result$b[2], result$se[2], result$ci.lb[2], result$ci.ub[2], result$k, result$pval[2], result$tau2, result$I2, result$H2, result$QE, result$QEp, result$QM, result$QMp))

# Investigate the possible influence of slope as moderator 
result = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Gwl_diff, sei = Gwl_diff_SE, test = "knha", weights = True_reps, mods = ~ Slope)
result

df <- rbind(df, c("gwl_diff_no_blanket_peatlands_moderator_slope", result$b[2], result$se[2], result$ci.lb[2], result$ci.ub[2], result$k, result$pval[2], result$tau2, result$I2, result$H2, result$QE, result$QEp, result$QM, result$QMp))

pdf("restore_mod_metareg_slope.pdf", height = 5, width = 5)
regplot(result, mod = "Slope", xlim=c(0,6), predlim=c(0,6), xlab="Slope (degrees)", ylab = "Change in groundwater level (cm)")
dev.off() 

# Investigate the possible influence of maximum sampled distance as moderator 
# Not used as reviewers pointed out that the 2 limnic shore wetlands distort effects, should be only peatlands
# result = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Gwl_diff, sei = Gwl_diff_SE, test = "knha", weights = True_reps, mods = ~ Max_dist_for_gwl_sampling)
# result

# df <- rbind(df, c("gwl_diff_no_blanket_peatlands_moderator_max_dist_for_gwl_sampling", result$b[2], result$se[2], result$ci.lb[2], result$ci.ub[2], result$k, result$pval[2], result$tau2, result$I2, result$H2, result$QE, result$QEp, result$QM, result$QMp))

# pdf("restore_mod_metareg_max_gwl_sampling_dist.pdf", height = 5, width = 5)
# regplot(result, mod = "Max_dist_for_gwl_sampling", xlim=c(0,300), predlim=c(0,300), xlab="Maximum distance of gwl sampling (m)", ylab = "Change in groundwater level (cm)", legend = TRUE)
# dev.off() 


# Investigate the possible influence of maximum sampled distance as moderator considering only peatlands
result = rma(measure = "MD", data = esd[AllPeatlandsExcludingBlanketPeatlands,], yi = Gwl_diff, sei = Gwl_diff_SE, test = "knha", weights = True_reps, mods = ~ Max_dist_for_gwl_sampling)
result

df <- rbind(df, c("gwl_diff_all_peatlands_excluding_blanket_peatlands_moderator_max_dist_for_gwl_sampling", result$b[2], result$se[2], result$ci.lb[2], result$ci.ub[2], result$k, result$pval[2], result$tau2, result$I2, result$H2, result$QE, result$QEp, result$QM, result$QMp))

pdf("restore_mod_metareg_max_gwl_sampling_dist_peatlands_excluding_blanket_peatlands_only.pdf", height = 5, width = 5)
regplot(result, mod = "Max_dist_for_gwl_sampling", xlim=c(0,300), predlim=c(0,300), xlab="Maximum distance of gwl sampling (m)", ylab = "Change in groundwater level (cm)", legend = TRUE)
dev.off() 



# Investigate the possible influence of open or closed transect as moderator 
result = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Gwl_diff, sei = Gwl_diff_SE, test = "knha", weights = True_reps, mods = ~ factor(Transect_type))
result

# Investigate the possible influence of intervention type as moderator 
result = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Gwl_diff, sei = Gwl_diff_SE, test = "knha", weights = True_reps, mods = ~ factor(Intervention_type_primary))
result

df <- rbind(df, c("gwl_diff_no_blanket_peatlands_moderator_intervention_type", result$b[2], result$se[2], result$ci.lb[2], result$ci.ub[2], result$k, result$pval[2], result$tau2, result$I2, result$H2, result$QE, result$QEp, result$QM, result$QMp))



# Sensitivity analyses
# -------------------

# Test the sensitivity to replication tyoe 
result = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Gwl_diff, sei = Gwl_diff_SE, test = "knha", mods = ~factor(Gwl_diff_Replication) - 1, weights = True_reps)
result

pdf("restore_mod_replication.pdf", height = 4)
forest(result$b, sei = result$se, header = c("Type of replication", "Raw mean difference [95% CI]"),
		slab = c("Spatial pseudoreplication", "True replication"),
		ilab = colSums(result$X), ilab.xpos = -6,
		xlim = c(-45, 65), 
		digits = c(decimals_rows, decimals_axis),
		xlab = "Change in groundwater level (cm)", psize = 1
)
par(font=2)
text(-6, 4, "n")
dev.off()

# Investigate the factor as a whole
result = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Gwl_diff, sei = Gwl_diff_SE, test = "knha", mods = ~factor(Gwl_diff_Replication), weights = True_reps)
result

df <- rbind(df, c("gwl_diff_no_blanket_peatlands_sensitivity_replication_type", result$b[2], result$se[2], result$ci.lb[2], result$ci.ub[2], result$k, result$pval[2], result$tau2, result$I2, result$H2, result$QE, result$QEp, result$QM, result$QMp))

# Investigate the possible influence of study design as moderator
res_design = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Gwl_diff, sei = Gwl_diff_SE, test = "knha", mods = ~factor(Study_design) - 1, weights = True_reps)
res_design

pdf("restore_mod_design.pdf", height = 4)
forest(res_design$b, sei = res_design$se, header = c("Study design", "Raw mean difference [95% CI]"),
		slab = str_replace(row.names(res_design$b), "factor\\(Study_design\\)", ""),
		ilab = colSums(res_design$X), ilab.xpos = -10,
		# xlim = c(-85, 35), 
		digits = c(decimals_rows, decimals_axis),
		xlab = "Change in groundwater level (cm)", psize = 1
)
par(font=2)
text(-10, 5, "n")
dev.off()

# Investigate the factor as a whole
result = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Gwl_diff, sei = Gwl_diff_SE, test = "knha", mods = ~factor(Study_design), weights = True_reps)
result

df <- rbind(df, c("gwl_diff_no_blanket_peatlands_sensitivity_study_design", result$b[2], result$se[2], result$ci.lb[2], result$ci.ub[2], result$k, result$pval[2], result$tau2, result$I2, result$H2, result$QE, result$QEp, result$QM, result$QMp))

# Investigate the possible influence of groundwater level reference point as moderator
result = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Gwl_diff, sei = Gwl_diff_SE, test = "knha", mods = ~factor(Gwl_ref_point), weights = True_reps)
result

df <- rbind(df, c("gwl_diff_no_blanket_peatlands_sensitivity_gwl_ref_point", result$b[2], result$se[2], result$ci.lb[2], result$ci.ub[2], result$k, result$pval[2], result$tau2, result$I2, result$H2, result$QE, result$QEp, result$QM, result$QMp))

pdf("restore_mod_gwl_ref_point.pdf", height = 4, width = 14)
result = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Gwl_diff, sei = Gwl_diff_SE, test = "knha", mods = ~factor(Gwl_ref_point) - 1, weights = True_reps)
forest(result$b, sei = result$se, header = c("GWL reference point", "Raw mean difference [95% CI]"),
		slab = str_replace(row.names(result$b), "factor\\(Gwl_ref_point\\)", ""),
		ilab = colSums(result$X), ilab.xpos = -55,
		xlim = c(-350, 120), 
		digits = c(decimals_rows, decimals_axis),
		xlab = "Change in groundwater level (cm)", psize = 1
)
par(font=2)
text(-55, 7, "n")
dev.off()

# Investigate the possible influence of climate zone as moderator
# Remove categories with just 1 study in the subgroup (too few to analyze)
esd_clim = esd[NoBlanketPeatlands,]
esd_clim <- esd_clim[!(esd_clim$"Climate_zone" == "Dsb") & !(esd_clim$"Climate_zone" == "Dwc"),]

result = rma(measure = "MD", data = esd_clim, yi = Gwl_diff, sei = Gwl_diff_SE, test = "knha", mods = ~factor(Climate_zone), weights = True_reps)
result

df <- rbind(df, c("gwl_diff_no_blanket_peatlands_moderator_climate_zone", result$b[2], result$se[2], result$ci.lb[2], result$ci.ub[2], result$k, result$pval[2], result$tau2, result$I2, result$H2, result$QE, result$QEp, result$QM, result$QMp))

pdf("restore_mod_climate_zone.pdf", height = 4)
result = rma(measure = "MD", data = esd_clim, yi = Gwl_diff, sei = Gwl_diff_SE, test = "knha", mods = ~factor(Climate_zone) - 1, weights = True_reps)
forest(result$b, sei = result$se, header = c("Climate zone", "Raw mean difference [95% CI]"),
		slab = str_replace(row.names(result$b), "factor\\(Climate_zone\\)", ""),
		ilab = colSums(result$X), ilab.xpos = -5,
		digits = c(decimals_rows, decimals_axis),
		xlab = "Change in groundwater level (cm)", psize = 1
)
par(font=2)
text(-5, 5, "n")
dev.off()



# Sensitivity test - study weighting
# -----------------------------------------------

# Investigate the possible influence of weighting by true replications or by variance estimate
# All studies
result = rma(measure = "MD", data = esd, yi = Gwl_diff, sei = Gwl_diff_SE, test = "knha")
result

df <- rbind(df, c("gwl_diff_sensitivity_weights_as_study_se", result$b, result$se, result$ci.lb, result$ci.ub, result$k, result$pval, result$tau2, result$I2, result$H2, result$QE, result$QEp, NA, NA))

# No blanket peatlands
result = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Gwl_diff, sei = Gwl_diff_SE, test = "knha")
result

df <- rbind(df, c("gwl_diff_no_blanket_peatlands_sensitivity_weights_as_study_se", result$b, result$se, result$ci.lb, result$ci.ub, result$k, result$pval, result$tau2, result$I2, result$H2, result$QE, result$QEp, NA, NA))

# Make a funnel plot of effect size vs study variance
pdf("restore_funnel.pdf", height = 4, width = 4)
funnel(result, xlab = "Raw mean difference")
dev.off() 

# Perform Egger's test of funnel plot assymetry
rt = regtest(result)
df <- rbind(df, c("gwl_diff_no_blanket_peatlands_eggers_test_weights_as_study_se", rt$est, NA, rt$ci.lb, rt$ci.ub, NA, rt$pval, NA, NA, NA, NA, NA, NA, NA))

# Perform trim and fill
taf = trimfill(result)
df <- rbind(df, c("gwl_diff_no_blanket_peatlands_trim_and_fill_est_missing_studies", taf$k0, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA))

# Plot trim and fill results
pdf("restore_funnel_trim_and_fill.pdf", height = 4, width = 4)
funnel(taf, xlab = "Raw mean difference")
dev.off() 


# Also prepare the funnel plot without outliers
result = rma(measure = "MD", data = esd[esd$Gwl_diff_SE < 10 & esd$Gwl_diff < 100,], yi = Gwl_diff, sei = Gwl_diff_SE, test = "knha")
pdf("restore_funnel_without_outliers.pdf", height = 4, width = 4)
funnel(result, xlab = "Raw mean difference")
dev.off() 


# Sensitivity test - remove studies with high risk of bias
# -----------------------------------------------

# Test results when retaining only studies with at least four occurrences of "low risk of bias"
# All studies
AtLeastFourLowRoB = (rowSums(esd == "Low risk", na.rm = TRUE) > 3)

result = rma(measure = "MD", data = esd[AtLeastFourLowRoB,], yi = Gwl_diff, sei = Gwl_diff_SE, test = "knha")
result

df <- rbind(df, c("gwl_diff_sensitivity_min_four_low_rob", result$b, result$se, result$ci.lb, result$ci.ub, result$k, result$pval, result$tau2, result$I2, result$H2, result$QE, result$QEp, NA, NA))

AtLeastFourLowRoBNoBlanketPeatlands = (rowSums(esd == "Low risk", na.rm = TRUE) > 3) & NoBlanketPeatlands

result = rma(measure = "MD", data = esd[AtLeastFourLowRoBNoBlanketPeatlands ,], yi = Gwl_diff, sei = Gwl_diff_SE, test = "knha")
result

df <- rbind(df, c("gwl_diff_no_blanket_peatlands_sensitivity_min_four_low_rob", result$b, result$se, result$ci.lb, result$ci.ub, result$k, result$pval, result$tau2, result$I2, result$H2, result$QE, result$QEp, NA, NA))

# Sensitivity test for limnic shore wetlands - remove one study whose effects far exceeds that of other studies
# -----------------------------------------------
# Remove Loheide 2007
WithoutLoheide2007 = esd$Short_ref != "Loheide 2007"
result = rma(measure = "MD", data = esd[WithoutLoheide2007,], yi = Gwl_diff, sei = Gwl_diff_SE, test = "knha", weights = True_reps)
result

# Fit random-effects model in the subgroups (only Limnic shore wetlands are of interest here)
res.l <- rma(measure = "MD", data = esd[WithoutLoheide2007,], subset = (Wetland_type == "Limnic shore wetland"), yi = Gwl_diff, sei = Gwl_diff_SE, test = "knha", weights = True_reps)

# Add results to df for later export
df <- rbind(df, c("gwl_diff_limnic_without_Loheide_2007", res.l$b, res.l$se, res.l$ci.lb, res.l$ci.ub, res.l$k, res.l$pval, res.l$tau2, res.l$I2, res.l$H2, res.l$QE, res.l$QEp, NA, NA))


# Save meta-analysis results to file
write.xlsx(df, paste(output_dir, "meta-analysis_results_restore.xlsx", sep = "/"))

